"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var observable_1 = require("tns-core-modules/data/observable");
var app = require("tns-core-modules/application");
var permissions = require('nativescript-permissions');
var AudioPickActivity = com.vincent.filepicker.activity.AudioPickActivity;
var ImagePickActivity = com.vincent.filepicker.activity.ImagePickActivity;
var NormalFilePickActivity = com.vincent.filepicker.activity.NormalFilePickActivity;
var VideoPickActivity = com.vincent.filepicker.activity.VideoPickActivity;
var Constant = com.vincent.filepicker.Constant;
var Intent = android.content.Intent;
var Mediafilepicker = (function (_super) {
    __extends(Mediafilepicker, _super);
    function Mediafilepicker() {
        return _super.call(this) || this;
    }
    Mediafilepicker.prototype.openImagePicker = function (params) {
        var intent, pickerType, options = params.android;
        intent = new Intent(app.android.foregroundActivity, ImagePickActivity.class);
        options.isNeedCamera ? intent.putExtra(ImagePickActivity.IS_NEED_CAMERA, true) : intent.putExtra(ImagePickActivity.IS_NEED_CAMERA, false);
        options.maxNumberFiles ? intent.putExtra(Constant.MAX_NUMBER, options.maxNumberFiles) : intent.putExtra(Constant.MAX_NUMBER, 99);
        options.isNeedFolderList ? intent.putExtra(ImagePickActivity.IS_NEED_FOLDER_LIST, true) : intent.putExtra(ImagePickActivity.IS_NEED_FOLDER_LIST, false);
        pickerType = Constant.REQUEST_CODE_PICK_IMAGE;
        this.callIntent(intent, pickerType);
    };
    Mediafilepicker.prototype.openVideoPicker = function (params) {
        var intent, pickerType, options = params.android;
        intent = new Intent(app.android.foregroundActivity, VideoPickActivity.class);
        options.isNeedCamera ? intent.putExtra(VideoPickActivity.IS_NEED_CAMERA, true) : intent.putExtra(VideoPickActivity.IS_NEED_CAMERA, false);
        options.maxNumberFiles ? intent.putExtra(Constant.MAX_NUMBER, options.maxNumberFiles) : intent.putExtra(Constant.MAX_NUMBER, 99);
        options.isNeedFolderList ? intent.putExtra(VideoPickActivity.IS_NEED_FOLDER_LIST, true) : intent.putExtra(VideoPickActivity.IS_NEED_FOLDER_LIST, false);
        if (options.maxDuration > 0) {
            intent.putExtra(Constant.MAX_VIDEO_DURATION, options.maxDuration);
        }
        intent.putExtra(Constant.VIDEO_QUALITY, 1);
        if (options.videoQuality === 0) {
            intent.putExtra(Constant.VIDEO_QUALITY, 0);
        }
        pickerType = Constant.REQUEST_CODE_PICK_VIDEO;
        this.callIntent(intent, pickerType);
    };
    Mediafilepicker.prototype.openAudioPicker = function (params) {
        var intent, pickerType, options = params.android;
        intent = new Intent(app.android.foregroundActivity, AudioPickActivity.class);
        options.isNeedRecorder ? intent.putExtra(AudioPickActivity.IS_NEED_RECORDER, true) : intent.putExtra(AudioPickActivity.IS_NEED_RECORDER, false);
        options.maxNumberFiles ? intent.putExtra(Constant.MAX_NUMBER, options.maxNumberFiles) : intent.putExtra(Constant.MAX_NUMBER, 99);
        options.isNeedFolderList ? intent.putExtra(AudioPickActivity.IS_NEED_FOLDER_LIST, true) : intent.putExtra(AudioPickActivity.IS_NEED_FOLDER_LIST, false);
        if (options.maxSize > 0) {
            intent.putExtra(Constant.MAX_AUDIO_SIZE, options.maxSize);
        }
        intent.putExtra(AudioPickActivity.IS_TAKEN_AUTO_SELECTED, true);
        pickerType = Constant.REQUEST_CODE_PICK_AUDIO;
        this.callIntent(intent, pickerType);
    };
    Mediafilepicker.prototype.openFilePicker = function (params) {
        var intent, pickerType, options = params.android, extensions;
        if (options.extensions.length > 0) {
            extensions = Array.create(java.lang.String, options.extensions.length);
            for (var i = 0; i < options.extensions.length; i++) {
                extensions[i] = options.extensions[i];
            }
        }
        intent = new Intent(app.android.foregroundActivity, NormalFilePickActivity.class);
        options.maxNumberFiles ? intent.putExtra(Constant.MAX_NUMBER, options.maxNumberFiles) : intent.putExtra(Constant.MAX_NUMBER, 99);
        intent.putExtra(NormalFilePickActivity.SUFFIX, extensions);
        pickerType = Constant.REQUEST_CODE_PICK_FILE;
        this.callIntent(intent, pickerType);
    };
    Mediafilepicker.prototype.callIntent = function (intent, pickerType) {
        var t = this;
        permissions.requestPermission([android.Manifest.permission.CAMERA, android.Manifest.permission.RECORD_AUDIO, android.Manifest.permission.WRITE_EXTERNAL_STORAGE], "Need these permissions to access files")
            .then(function () {
            app.android.foregroundActivity.startActivityForResult(intent, pickerType);
        })
            .catch(function () {
            t.msg = "Permission Error!";
            t.notify({
                eventName: 'error',
                object: t
            });
        });
        app.android.on(app.AndroidApplication.activityResultEvent, onResult);
        function onResult(args) {
            app.android.off(app.AndroidApplication.activityResultEvent, onResult);
            t.handleResults(args.requestCode, args.resultCode, args.intent);
        }
    };
    Mediafilepicker.prototype.handleResults = function (requestCode, resultCode, data) {
        var _this = this;
        var androidAcivity = android.app.Activity;
        var output = [];
        var t = this;
        switch (requestCode) {
            case Constant.REQUEST_CODE_PICK_IMAGE:
                if (resultCode === androidAcivity.RESULT_OK) {
                    var list = data.getParcelableArrayListExtra(Constant.RESULT_PICK_IMAGE);
                    list = list.toArray();
                    for (var index_1 = 0; index_1 < list.length; index_1++) {
                        var item = list[index_1];
                        var file = {
                            type: 'image',
                            file: item.getPath(),
                            rawData: item
                        };
                        output.push(file);
                    }
                }
                break;
            case Constant.REQUEST_CODE_PICK_VIDEO:
                if (resultCode === androidAcivity.RESULT_OK) {
                    var list = data.getParcelableArrayListExtra(Constant.RESULT_PICK_VIDEO);
                    list = list.toArray();
                    for (var index_2 = 0; index_2 < list.length; index_2++) {
                        var item = list[index_2];
                        var file = {
                            type: 'video',
                            file: item.getPath(),
                            rawData: item
                        };
                        output.push(file);
                    }
                }
                break;
            case Constant.REQUEST_CODE_PICK_AUDIO:
                if (resultCode === androidAcivity.RESULT_OK) {
                    var list = data.getParcelableArrayListExtra(Constant.RESULT_PICK_AUDIO);
                    list = list.toArray();
                    for (var index_3 = 0; index_3 < list.length; index_3++) {
                        var item = list[index_3];
                        var file = {
                            type: 'audio',
                            file: item.getPath(),
                            rawData: item
                        };
                        output.push(file);
                    }
                }
                break;
            case Constant.REQUEST_CODE_PICK_FILE:
                if (resultCode === androidAcivity.RESULT_OK) {
                    var list = data.getParcelableArrayListExtra(Constant.RESULT_PICK_FILE);
                    list = list.toArray();
                    for (var index_4 = 0; index_4 < list.length; index_4++) {
                        var item = list[index_4];
                        var file = {
                            type: 'normalFile',
                            file: item.getPath(),
                            rawData: item
                        };
                        output.push(file);
                    }
                }
                break;
        }
        setTimeout(function () {
            _this.results = output;
            t.notify({
                eventName: 'getFiles',
                object: t
            });
        }, 500);
    };
    return Mediafilepicker;
}(observable_1.Observable));
exports.Mediafilepicker = Mediafilepicker;
//# sourceMappingURL=mediafilepicker.android.js.map